@@ -1,11 +1,16 @@
-from django.db.models import BooleanField, NullBooleanField
+from typing import Any, Optional
+
+from django.db.backends.base.base import BaseDatabaseWrapper
+from django.db.models import BooleanField, Expression, NullBooleanField
 
 
 class Bit1Mixin:
-    def db_type(self, connection):
+    def db_type(self, connection: BaseDatabaseWrapper) -> str:
         return "bit(1)"
 
-    def from_db_value(self, value, expression, connection):
+    def from_db_value(
+        self, value: Any, expression: Expression, connection: BaseDatabaseWrapper
+    ) -> Any:
         # Meant to be binary/bytes but can come back as unicode strings
         if isinstance(value, bytes):
             value = value == b"\x01"
@@ -14,7 +19,7 @@ class Bit1Mixin:
             value = value == "\x01"  # pragma: no cover
         return value
 
-    def get_prep_value(self, value):
+    def get_prep_value(self, value: Any) -> Optional[int]:
         if value is None:
             return value
         else:
