@@ -114,7 +114,6 @@ if django.VERSION >= (3, 0):
     def connection_is_mariadb(connection: BaseDatabaseWrapper) -> bool:
         return connection.vendor == "mysql" and connection.mysql_is_mariadb
 
-
 else:
 
     _is_mariadb_cache: Mapping[BaseDatabaseWrapper, bool] = WeakKeyDictionary()
@@ -129,7 +128,7 @@ else:
         try:
             return _is_mariadb_cache[connection]
         except KeyError:
-            with connection.temporary_connection():
+            with connection.temporary_connection():  # pragma: no branch
                 server_info: str = connection.connection.get_server_info()
             is_mariadb = "MariaDB" in server_info
             _is_mariadb_cache[connection] = is_mariadb  # type: ignore [index]
@@ -189,7 +188,7 @@ def pt_fingerprint(query: str) -> str:
     return thread.out_queue.get()
 
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     PTFingerPrintQueueType = Queue[str]
 else:
     PTFingerPrintQueueType = Queue
